@@ -1049,7 +1049,7 @@ var QUERIES = {
     matches: [],
     regexp: /^(firefox|ff|fx)\s+esr$/i,
     select: function () {
-      return ['firefox 128']
+      return ['firefox 128', 'firefox 140']
     }
   },
   opera_mini_all: {
